==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/mysys/mf_unixpath.cc <==
/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   Without limiting anything contained in the foregoing, this file,
   which is part of C Driver for MySQL (Connector/C), is also subject to the
   Universal FOSS Exception, version 1.0, a copy of which can be found at
   http://oss.oracle.com/licenses/universal-foss-exception.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/**
  @file mysys/mf_unixpath.cc
*/

/**
  Convert filename to unix style filename.

  @remark On Windows, converts '\' to '/'.

  @param to   A pathname.
*/

#include "my_compiler.h"
#include "my_io.h"

void to_unix_path(char *to [[maybe_unused]]) {
#if FN_LIBCHAR != '/'
  {
    to--;
    while ((to = strchr(to + 1, FN_LIBCHAR)) != 0) *to = '/';
  }
#endif
}

==> mysql-8.0.26.tar.gz: mysql-8.0.26/mysys/mf_unixpath.cc <==
/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   Without limiting anything contained in the foregoing, this file,
   which is part of C Driver for MySQL (Connector/C), is also subject to the
   Universal FOSS Exception, version 1.0, a copy of which can be found at
   http://oss.oracle.com/licenses/universal-foss-exception.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/**
  @file mysys/mf_unixpath.cc
*/

/**
  Convert filename to unix style filename.

  @remark On Windows, converts '\' to '/'.

  @param to   A pathname.
*/

#include "my_compiler.h"
#include "my_io.h"

void to_unix_path(char *to MY_ATTRIBUTE((unused))) {
#if FN_LIBCHAR != '/'
  {
    to--;
    while ((to = strchr(to + 1, FN_LIBCHAR)) != 0) *to = '/';
  }
#endif
}
